@@ -1,6 +1,8 @@
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
+import sys
+
 import numpy as np
 from numpy.testing import assert_array_almost_equal
 import matplotlib.pyplot as plt
@@ -8,6 +10,9 @@ from matplotlib.testing.decorators import image_comparison
 import matplotlib.transforms as mtransforms
 
 
+on_win = (sys.platform == 'win32')
+
+
 def velocity_field():
     Y, X = np.mgrid[-3:3:100j, -3:3:100j]
     U = -1 - X**2 + Y
@@ -36,7 +41,7 @@ def test_startpoints():
 
 
 @image_comparison(baseline_images=['streamplot_colormap'],
-                  tol=0.002)
+                  tol=.02)
 def test_colormap():
     X, Y, U, V = velocity_field()
     plt.streamplot(X, Y, U, V, color=U, density=0.6, linewidth=2,
@@ -54,7 +59,8 @@ def test_linewidth():
                    linewidth=lw)
 
 
-@image_comparison(baseline_images=['streamplot_masks_and_nans'])
+@image_comparison(baseline_images=['streamplot_masks_and_nans'],
+                  tol=0.04 if on_win else 0)
 def test_masks_and_nans():
     X, Y, U, V = velocity_field()
     mask = np.zeros(U.shape, dtype=bool)
